pub enum LookupTableType {
BitPoly {
width: usize,
chunk_width: Option<usize>,
},
Word {
width: usize,
chunk_width: Option<usize>,
},
}Expand description
Describes the type of lookup table a column should be checked against.
Full table size = 2^width for each type; decomposed into chunks of
chunk_width
Variants
BitPoly
Binary polynomials of degree less than width, projected into the prime
field.
Word
Unsigned integers fitting in width bits.