pub struct LookupColumnSpec {
pub column_index: usize,
pub table_type: LookupTableType,
}Expand description
Specifies that a trace column should be looked up against a prescribed table.
Fields
column_index: usize0-based index into the projected field-element trace.
table_type: LookupTableTypeThe lookup table type this column should be checked against.